@@ -6,8 +6,8 @@ bool Args::makelist(Builtin::ArgsIter funBegin, Builtin::ArgsIter funEnd,
 {
     if (argEnd - argBegin == 0)                     // zero trailing args: OK
         return true;
-
-    if (funEnd - funBegin != argEnd - argBegin)     // # specs/args differ
+                                                    // # specs/args differ
+    if (int argDiff = argEnd - argBegin; funEnd - funBegin != argDiff)     
         return false;
 
                                                     // check trailing args
