@@ -1,18 +1,16 @@
 #define XERR
 #include "main.ih"
 
-#include "../tmp/INSTALL.im"
-
 namespace
 {
     Arg::LongOption longOpts[] =
     {
         Arg::LongOption{"classes",      'c'             },
-        Arg::LongOption{"gch",          Arg::None       },
+        Arg::LongOption{"gch",          Arg::NoArg      },
         Arg::LongOption{"help",         'h'             },
         Arg::LongOption{"mainih",       'm'             },
-        Arg::LongOption{"no-gch",       Arg::None       },
-        Arg::LongOption{"no-use-all",   Arg::None       },
+        Arg::LongOption{"no-gch",       Arg::NoArg      },
+        Arg::LongOption{"no-use-all",   Arg::NoArg      },
         Arg::LongOption{"use-all",      Arg::Required   },
         Arg::LongOption{"verbose",      'V'             },
         Arg::LongOption{"version",      'v'             },
@@ -42,17 +40,7 @@ try
     dependencies.useAll();          // when requested: check the useAll files
     dependencies.gchFiles();        // when requested: check the .gch files
 }
-catch(int x)
-{
-    return Arg::instance().option("hv") ? 0 : x;
-}
-catch (exception const &exc)
-{
-    cerr << exc.what() << '\n';
-}
-
 catch (...)
 {
-    cerr << "unexpected exception\n";
-    return 1;
+    return handleException();
 }
