@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "direct"
 #include "direct.ih"
 
 int Direct::run(char const *progName, Base::ExecType type)
