@@ -1,4 +1,4 @@
-#define XERR
+#define XERR "options"
 #include "options.ih"
 
 bool Options::source()
@@ -6,6 +6,5 @@ bool Options::source()
     checkAction(SOURCE);
 
     d_optBase = new SourceOpts{ d_argv };
-
     return false;           // no further actions wrt processing options
 }
