@@ -1,6 +1,8 @@
-#define XERR
+#define XERR "scriptopts"
 #include "scriptopts.ih"
 
+    // by addarguments.cc
+
 void ScriptOpts::addImAndBim()
 {                                   // determine the temp. imname
     char *tmpIm = imName();         // (script w/o #!-line -> TempStream
