@@ -1,19 +1,21 @@
-#define XERR
+#define XERR "scriptopts"
 #include "scriptopts.ih"
 
-    //----------------------------------------------------------------------
-    //     arg1:        a dir?      tmpDir:     d_bimName:      TempStream?
-    //----------------------------------------------------------------------
-    //  1:  .               unused      tmpDir()    tmpDir()        yes
-    //  2: [~]/dir/         yes         [~]/dir     tmpDir()        yes
-    //  3: [~]/dir/name     no          [~]/dir                     no
-    //----------------------------------------------------------------------
+//----------------------------------------------------------------------
+//     arg1:        a dir?      tmpDir:     d_bimName:      TempStream?
+//----------------------------------------------------------------------
+//  1:  .               unused      tmpDir()    tmpDir()        yes
+//  2: [~]/dir/         yes         [~]/dir     tmpDir()        yes
+//  3: [~]/dir/name     no          [~]/dir                     no
+//----------------------------------------------------------------------
+
+    // by reset.cc
 
 void ScriptOpts::setBim(string arg1)            // 1st argument of -t
 {
     if (arg1 == ".")                            // 1st alternative: -t.
     {
-        tmpBim(tmpDir());
+        tmpBim();
         return;                                 // a std. temp. name
     }
 
@@ -24,7 +26,9 @@ void ScriptOpts::setBim(string arg1)            // 1st argument of -t
     if (isDir(arg1))                            // 2nd alternative: 
     {                                           // -tdir/
         setTmpDir(arg1);
-        tmpBim(arg1);
+        setTmp();
+        tmpBim();
+
         return;
     }
 
@@ -33,6 +37,7 @@ void ScriptOpts::setBim(string arg1)            // 1st argument of -t
 
     arg1 = fs::path{ arg1 }.parent_path();      // 'string &' needed:
     setTmpDir(arg1);                            // update tmpDir()
+    setTmp();
 }
 
 
