@@ -1,6 +1,8 @@
-#define XERR
+#define XERR "sourceopts"
 #include "sourceopts.ih"
 
+    // by sourceopts1.cc
+
 void SourceOpts::addImAndBim(size_t idx)
 {
     char *imFile = d_argv[idx];             // the file to compile
@@ -9,7 +11,7 @@ void SourceOpts::addImAndBim(size_t idx)
 
     d_compile.push_back(imFile);            // add as 1st non option
 
-    d_bim = new TempStream{ tmpDir() };
+    d_bim = new TempStream{ tmp() };
     char *bimFile = d_Args.add(d_bim->fileName());  // get the .bim filename
 
     d_compile.push_back(bimFile);      // compile to .bim
