@@ -1,6 +1,8 @@
-#define XERR
+#define XERR "sourcescript"
 #include "sourcescript.ih"
 
+    // by handler/sourcescript.cc
+
 int SourceScript::run() const
 {
     if (int ret = compile(); ret != 0)
