@@ -6,7 +6,7 @@ class OptBase;
 
 class SourceScript
 {
-    STBase &d_stBase;
+    STBase &d_stBase;           // ScriptOpts with -t, SourceOpts with -s
 
     public:
         SourceScript(OptBase &optBase);
