@@ -15,6 +15,10 @@ class STBase: public OptBase
     bool d_skipCompile;             // by default false (compilation is 
                                     // performed) but true at -tdir if 
                                     // scriptname younger scriptname.bim
+
+    std::string d_tmp;              // set to tmpDir()/src() when using -t/-s
+                                    // otherwise tmpDir()
+
     protected:
         Args   &d_Args;
 
@@ -25,12 +29,15 @@ class STBase: public OptBase
         STBase(PtrVect &argv);
         ~STBase() override;
 
-        PreCompOpts compileOpts();                  // inline (2x)
+        PreCompOpts compileOpts();                                  // .f
         DirectOpts  executeOpts();
 
-        bool script() const;                        // inline (3x)
-        bool skipCompile() const;
-        void setSkipCompile(bool value);
+        bool script() const;                        
+        bool skipCompile() const;                                   // .f
+        void setSkipCompile(bool value);                            // .f
+
+        void setTmp();
+        std::string const &tmp() const;                             // .f
 
     protected:
                                 // returns the 1st non-option idx or str::npos
@@ -42,19 +49,6 @@ class STBase: public OptBase
         bool eOption();
 };
 
-inline bool STBase::skipCompile() const
-{
-    return d_skipCompile;
-}
-
-inline void STBase::setSkipCompile(bool value)
-{
-    d_skipCompile = value;
-}
-
-inline PreCompOpts STBase::compileOpts()
-{
-    return PreCompOpts{ d_compile, "d:hv", Base::COMPILE };
-}
+#include "stbase.f"
 
 #endif
