@@ -3,7 +3,7 @@
 
 bool Modules::clean()
 {
-    if (not d_clean)
+    if (not d_options.clean())
         return false;
 
     d_classes.reset();
