@@ -9,12 +9,14 @@
 bool Modules::linked(Path const &extModgcm, size_t unknownIdx)
 {
                                     // extModgcm is the searched Module ?
-    if (extModgcm.filename().string() != d_scan.gcmName(unknownIdx))
+    if (extModgcm.filename().string() 
+            != gcmName(d_modVect[unknownIdx].modName())
+    )
         return false;               // no: done here
 
                                     // yes: add it (+ required modules)
 
-    d_scan.setExtern(unknownIdx);   // not UNKNOWN anymore: now EXTERN
+    d_modVect[unknownIdx].setExtern();   // not UNKNOWN anymore: now EXTERN
     d_unknowns.erase(unknownIdx);
 
     connect(extModgcm);             // extModgcm may depend on its own modules
