@@ -5,9 +5,9 @@
 
 bool Modules::unknowns()
 {
-    for (size_t idx = 0, end = d_scan.modVect().size(); idx != end; ++idx)
+    for (size_t idx = 0, end = d_modVect.size(); idx != end; ++idx)
     {
-        if (d_scan.modVect(idx).type() == ModData::UNKNOWN)
+        if (d_modVect[idx].type() == ModData::UNKNOWN)
             d_unknowns.insert(idx);
     }
 
