@@ -14,8 +14,13 @@ void Scan::definePartition()
 
     imsg << "       defines partition " << matched << endl;
 
+    // partitions require their modules, so the module is imorted by the
+    // partition (below)
+
+    string modName{ matched.substr(0, matched.find(':')) };
+
                                     // declare the module, get its index
-    d_nameIdx = declare(matched.substr(0, matched.find(':')));
+    d_nameIdx = declare(modName);
 
                                     // define the partition Name:Part
     d_currentIdx = define(matched); // and set d_current
