@@ -1,7 +1,8 @@
 #define XERR
 #include "support.ih"
 
-void Support::createSymlink(Path const &dest, Path const &link) const
+// static
+void Support::createSymlink(Path const &dest, Path const &link) 
 {
     string msg { "soft-link from " + link.string() + " -> " + dest.string() };
 
