@@ -31,19 +31,7 @@ try
 
     return state.run();
 }
-catch (int retValue)
-{
-    return retValue;
-}
-catch (exception const &exc)
-{
-    cerr << exc.what() << '\n';
-    return 1;
-}
 catch (...)
 {
-    cerr << "\n"
-            "fatal: unaccounted for exception\n";
-    return 1;
+    return handleException();
 }
-
