@@ -53,9 +53,10 @@ inline std::string const &Options::spchGch() const
     return d_spchGch;
 }
 
+    // by precompile.cc
 inline char const *Options::compilerArg() const
 {
-    return d_arg[1 + d_all];
+    return d_arg[1 + d_all];    // arg1 with -p, arg2 with -S
 }
 
 inline std::string const &Options::extraOptions() const
