@@ -7,8 +7,6 @@ int Process::precompile()
     string const &spch = d_options.spch();
     string const &spchGch = d_options.spchGch();
 
-//xerr("spchGch: " << spchGch << ", spch: " << spch);
-
     bool ok = recent(spchGch, spch);
     if (not ok)
     {
@@ -21,10 +19,12 @@ int Process::precompile()
                             d_options.extraOptions() + 
                             compilerSpec.substr(pos);
 
-//xerr("compiler spec. = `" << compilerSpec << '\'');
+        string cmd{ Tools::command(compilerSpec, spch, spchGch) };
+        if (not d_options.quiet())
+            cout << cmd << '\n';
 
         Exec exec;
-        exec.execute(Tools::command(compilerSpec, spch, spchGch));
+        exec.execute(cmd);
         ok =  exec.ret() == 0;
     }
 
