@@ -3,6 +3,12 @@
 
 int Process::run()
 {
+    if (d_options.all())
+        return 
+            spch() != 0       ? 1 :
+            precompile() != 0 ? 2 :
+            softLinks() != 0  ? 3 : 0;
+
     if (d_options.list())           // construct the ./spch file
         return spch();
 
@@ -12,6 +18,6 @@ int Process::run()
     if (d_options.softLink())       // construct the soft-links to dest.
         return softLinks();
 
-    throw Exception{} << "One of options --list, --precompile or --soft-links "
-                         "must be specified";
+    throw Exception{} << "at least one of --list, --precompile or "
+                         "--soft-links must be specified";
 }
